@@ -28,7 +28,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 /* prototype definitions */
 char *mysqldbname(char *, char *, int);
-char *mysqlsafestr(char *, char *, int);
 char *mysqlmatch(char *);
 char *strtolower(char *);
 char *strtoupper(char *);
@@ -131,7 +130,8 @@ void oer_debug(int level, const char *fmt, ...)
 		if((index(mystate->flags, (int)'o') != NULL) && (strstr(mystate->state, "+ro") == NULL)) {
 			/* do not use oer_doquery here and do not
 			   check for errors */
-			snprintf(query, WRITE_BUFFER_LENGTH, "INSERT INTO output VALUES (%lu, '%s', '%s')", mystate->now, mystate->ident, stringbuffer);
+			mysql_real_escape_string(&mystate->mysqldb.mysqldbconn, mysql_safe_str1, stringbuffer, strlen(stringbuffer));
+			snprintf(query, WRITE_BUFFER_LENGTH, "INSERT INTO output VALUES (%lu, '%s', '%s')", mystate->now, mystate->ident, mysql_safe_str1);
 			mysql_query(&mystate->mysqldb.mysqldbconn, query);
 		}
 		if(do_console) {
@@ -528,42 +528,6 @@ char *mysqldbname(char *from, char *to, int to_len)
 	return strtolower(to);
 }
 
-char *mysqlsafestr(char *from, char *to, int to_len)
-{
-	int i;
-	int k;
-        int len;
-	int bailout;
-
-	for(i = 0, k = 0, len = strlen(from), bailout = 0; i < len && k < to_len; i++) {
-		if(from[i] == '\'' || from[i] == '\\') {
-			if(k + 1 >= to_len) {
-				/* bail out */
-				bailout = 2;
-				break;
-			}
-			to[k++] = from[i];
-			to[k++] = from[i];
-		} else {
-			if(k >= to_len) {
-				/* bail out */
-				bailout = 1;
-				break;
-			}
-			to[k++] = from[i];
-		}
-        }
-#ifdef DEBUG
-	if(bailout == 1 || bailout == 2) {
-		/* insufficient buffer space */
-                oer_debug(OER_DEBUG_WARNING, "mysqlsafestr->source length at least %d, destination length %d\n", k + bailout, to_len);
-                oer_debug(OER_DEBUG_WARNING, "mysqlsafestr->destination buffer too small! E-mail equ@equnet.org for a fix\n");
-	}
-#endif
-	to[k] = '\0';
-	return to;
-}
-
 char *mysqlmatch(char *str)
 {
 	int i;
