@@ -42,11 +42,16 @@ fi
 $ECHO "ok"
 $ECHO ""
 
+HOST="localhost"
+DB="oerdb"
+DBUSER="oer"
+DBUSERPW=""
+
 readln "Do you want to create the database (+ user) for oer+MySQL? [y/N] " "N"
 CREATEDB=$ans
 
 if [ "$CREATEDB" = "y" -o "$CREATEDB" = "Y" ]; then
-    readln "Please specify the host where MySQL is running [localhost] " "localhost"
+    readln "Please specify the host where MySQL is running [$HOST] " "$HOST"
     HOST=$ans
     readln "Please specify the MySQL admin user [root] " "root"
     USER=$ans
@@ -76,7 +81,7 @@ if [ "$CREATEDB" = "y" -o "$CREATEDB" = "Y" ]; then
 
     $ECHO "ok"
     $ECHO
-    readln "What should your database be named [oerdb] " "oerdb"
+    readln "What should your database be named [$DB] " "$DB"
     DB=$ans
     $ECHO ""
     $ECHO -n "Attempting to create database... "
@@ -103,7 +108,7 @@ if [ "$CREATEDB" = "y" -o "$CREATEDB" = "Y" ]; then
     $ECHO "ok"
     $ECHO ""
 
-    readln "What database user will be granted rights to $DB [oer] " "oer"
+    readln "What database user will be granted rights to $DB [$DBUSER] " "$DBUSER"
     DBUSER=$ans
     stty -$ECHO
     readln "Please specify password for $DBUSER [] " ""
@@ -171,6 +176,20 @@ if [ "$CREATEDB" = "y" -o "$CREATEDB" = "Y" ]; then
 
     $ECHO "ok"
     $ECHO ""
+else
+    $ECHO ""
+    readln "Please specify the host where MySQL is running [$HOST] " "$HOST"
+    HOST=$ans
+    readln "Please specify the database [$DB] " "$DB"
+    DB=$ans
+    readln "Please specify the database user [$DBUSER] " "$DBUSER"
+    DBUSER=$ans
+    stty -$ECHO
+    readln "Please specify password for $DBUSER [] " ""
+    DBUSERPW=$ans
+    stty $ECHO
+    $ECHO ""
+    $ECHO ""
 fi
 
 if [ "$CREATEDB" = "y" -o "$CREATEDB" = "Y" ]; then
@@ -183,15 +202,6 @@ CREATETABLES=$ans
 
 if [ "$CREATETABLES" = "y" -o "$CREATETABLES" = "Y" ]; then
     if [ "$CREATEDB" = "n" -o "$CREATEDB" = "N" ]; then
-	readln "Please specify the host where MySQL is running [localhost] " "localhost"
-	HOST=$ans
-	readln "Please specify the database [oerdb] " "oerdb"
-	DB=$ans
-	readln "Please specify the database user [oer] " "oer"
-	DBUSER=$ans
-	stty -$ECHO
-	readln "Please specify password for $DBUSER [] " ""
-	DBUSERPW=$ans
 	stty $ECHO
 	$ECHO ""
 	$ECHO ""
